### PlotFig1.R

tmp1 <- subset(read.csv("mutrep2004-04-08.csv"),subset = !(compound=="vinyl chloride" & ADur == 5))
### Just keep the mutagens: DEN, safrole, urethane
tmp2 <- subset(read.csv("lifetime2004-04-08.csv"),
               subset=compound %in% c("DEN","safrole","urethane"))
repeated <- rbind(subset(tmp1,select=c("meanlratio1","varlratio1","Q2.5","Q97.5")),
                  subset(tmp2,select=c("meanlratio1","varlratio1","Q2.5","Q97.5")))
repeated$GM <- exp(repeated$meanlratio1)
repeated$Wt <- (1/repeated$varlratio1)/sum(1/repeated$varlratio1)
indx <- order(repeated$GM)
repeated <- repeated[indx,]
repeated$index <- seq(along=repeated$GM)
repeated$indx <- ppoints(length(repeated$GM))

acute <- subset(read.csv("mutacute2004-04-08.csv"),
                select=c("meanlratio1","varlratio1","Q2.5","Q97.5"))
acute$GM <- exp(acute$meanlratio1)
acute$Wt <- (1/acute$varlratio1)/sum(1/acute$varlratio1)
indx <- order(acute$GM)
acute <- acute[indx,]
acute$index <- seq(along=acute$GM)
acute$indx <- ppoints(length(acute$GM))

postscript(file="Fig12005-03-16.ps",onefile=FALSE,horizontal=FALSE,paper="special",
           width=6,height=7,pointsize=12)
par(mfcol=c(2,1),mar=c(5,5,0,0)+0.1,las=1)

### Repeated and lifetime exposures

plot(indx ~ GM, data=repeated, ylab="Cumulative Fraction",xaxt="n",
     xlab="Juvenile:Adult Ratio",log="x",cex=0.25,
     xlim=range(exp(c(repeated$Q2.5,repeated$Q97.5))))
with(repeated,segments(exp(Q2.5),indx,exp(Q97.5),indx))
axis(1,at=c(1e-03,1e-02,1e-01,1,10,1e02,1000),labels=expression(10^-3,10^-2,0.1,1,10,10^2,10^3))
abline(h=0.95)
abline(v=exp(weighted.mean(repeated$meanlratio1,repeated$Wt)))
abline(v=quantile(repeated$GM,prob=0.95),lty="dotted")

grid(ny=0)

### Acute Exposures

plot(indx ~ GM, data=acute, ylab="Cumulative Fraction",xaxt="n",xlab="Juvenile:Adult Ratio",
     log="x",cex=0.25,
     xlim=range(exp(c(acute$Q2.5,acute$Q97.5))))
with(acute,segments(exp(Q2.5),indx,exp(Q97.5),indx))
points(indx ~ GM, data=acute, cex=0.25, col="white")
axis(1,at=c(1e-03,1e-02,1e-01,1,10,1e02,1000),labels=expression(10^-3,10^-2,0.1,1,10,10^2,10^3))
abline(h=0.95)
abline(v=exp(weighted.mean(acute$meanlratio1,acute$Wt)))
abline(v=quantile(acute$GM,prob=0.95),lty="dotted")

grid(ny=0)
dev.off()
